@@ -53,7 +53,7 @@ class Parameters(Enum):
 
 
 def apply(event_log: Union[pd.DataFrame, EventLog, EventStream],
-          parameters: Optional[Dict[str, Any]] = None) -> Tuple[PetriNet, Marking, Marking]:
+          parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[PetriNet, Marking, Marking]:
     if parameters is None:
         parameters = {}
     tree = apply_tree(event_log, parameters=parameters)
@@ -92,7 +92,7 @@ def apply_tree_variants(variants, parameters=None):
 
 
 def apply_tree(event_log: Union[pd.DataFrame, EventLog, EventStream],
-               parameters: Optional[Dict[str, Any]] = None) -> ProcessTree:
+               parameters: Optional[Dict[Union[Parameters, str], Any]] = None) -> ProcessTree:
     if parameters is None:
         parameters = {}
     event_log = log_converter.apply(event_log, parameters=parameters)
@@ -123,7 +123,7 @@ def apply_tree(event_log: Union[pd.DataFrame, EventLog, EventStream],
 
 
 def inductive_miner(log, dfg, threshold, root, act_key, use_msd, remove_noise=False):
-    alphabet = pm4py.get_attribute_values(log, act_key)
+    alphabet = pm4py.get_event_attribute_values(log, act_key)
     if threshold > 0 and remove_noise:
         outgoing_max_occ = {}
         for x, y in dfg.items():
