@@ -30,7 +30,7 @@ class Variants(Enum):
 
 
 def apply(log_obj: Union[EventLog, pd.DataFrame, EventStream], variant: Union[str, None] = None,
-          parameters: Optional[Dict[str, Any]] = None):
+          parameters: Optional[Dict[Any, Any]] = None):
     if parameters is None:
         parameters = {}
 
