@@ -26,6 +26,7 @@ from pm4py.util.constants import PARAM_MOST_COMMON_VARIANT
 from enum import Enum
 from pm4py.util import exec_utils
 from copy import copy
+import deprecation
 
 
 class Parameters(Enum):
@@ -71,6 +72,7 @@ def apply(df, values, parameters=None):
                                        positive=positive, grouped_df=grouped_df)
 
 
+@deprecation.deprecated("2.2.11", "3.0.0", details="Removed")
 def apply_auto_filter(df, parameters=None):
     """
     Apply auto filter on end activities
