@@ -21,7 +21,6 @@ from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY, PARAMETER_CONSTANT_CASEID_KEY
-from pm4py.util.vers_checker import check_pandas_ge_024
 from enum import Enum
 from pm4py.util import exec_utils
 from copy import copy
@@ -60,12 +59,10 @@ def filter_traces_contained(df, dt1, dt2, parameters=None):
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    needs_conversion = check_pandas_ge_024()
-    if needs_conversion:
-        dt1 = dt1.replace(tzinfo=pytz.utc)
-        dt2 = dt2.replace(tzinfo=pytz.utc)
-        dt1 = pd.to_datetime(dt1, utc=True)
-        dt2 = pd.to_datetime(dt2, utc=True)
+    dt1 = dt1.replace(tzinfo=pytz.utc)
+    dt2 = dt2.replace(tzinfo=pytz.utc)
+    dt1 = pd.to_datetime(dt1, utc=True)
+    dt2 = pd.to_datetime(dt2, utc=True)
     grouped_df = df[[case_id_glue, timestamp_key]].groupby(df[case_id_glue])
     first = grouped_df.first()
     last = grouped_df.last()
@@ -109,12 +106,10 @@ def filter_traces_intersecting(df, dt1, dt2, parameters=None):
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    needs_conversion = check_pandas_ge_024()
-    if needs_conversion:
-        dt1 = dt1.replace(tzinfo=pytz.utc)
-        dt2 = dt2.replace(tzinfo=pytz.utc)
-        dt1 = pd.to_datetime(dt1, utc=True)
-        dt2 = pd.to_datetime(dt2, utc=True)
+    dt1 = dt1.replace(tzinfo=pytz.utc)
+    dt2 = dt2.replace(tzinfo=pytz.utc)
+    dt1 = pd.to_datetime(dt1, utc=True)
+    dt2 = pd.to_datetime(dt2, utc=True)
     grouped_df = df[[case_id_glue, timestamp_key]].groupby(df[case_id_glue])
     first = grouped_df.first()
     last = grouped_df.last()
@@ -162,12 +157,10 @@ def apply_events(df, dt1, dt2, parameters=None):
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    needs_conversion = check_pandas_ge_024()
-    if needs_conversion:
-        dt1 = dt1.replace(tzinfo=pytz.utc)
-        dt2 = dt2.replace(tzinfo=pytz.utc)
-        dt1 = pd.to_datetime(dt1, utc=True)
-        dt2 = pd.to_datetime(dt2, utc=True)
+    dt1 = dt1.replace(tzinfo=pytz.utc)
+    dt2 = dt2.replace(tzinfo=pytz.utc)
+    dt1 = pd.to_datetime(dt1, utc=True)
+    dt2 = pd.to_datetime(dt2, utc=True)
 
     ret = df[df[timestamp_key] >= dt1]
     ret = ret[ret[timestamp_key] <= dt2]
@@ -209,12 +202,10 @@ def filter_traces_attribute_in_timeframe(df, attribute, attribute_value, dt1, dt
     
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    needs_conversion = check_pandas_ge_024()
-    if needs_conversion:
-        dt1 = dt1.replace(tzinfo=pytz.utc)
-        dt2 = dt2.replace(tzinfo=pytz.utc)
-        dt1 = pd.to_datetime(dt1, utc=True)
-        dt2 = pd.to_datetime(dt2, utc=True)
+    dt1 = dt1.replace(tzinfo=pytz.utc)
+    dt2 = dt2.replace(tzinfo=pytz.utc)
+    dt1 = pd.to_datetime(dt1, utc=True)
+    dt2 = pd.to_datetime(dt2, utc=True)
     
     filtered = df[df[attribute] == attribute_value]
     filtered = filtered[filtered[timestamp_key] >= dt1]
