@@ -19,9 +19,10 @@ from typing import Tuple
 
 import deprecation
 
-from pm4py.objects.bpmn.bpmn_graph import BPMN
-from pm4py.objects.log.log import EventLog
-from pm4py.objects.petri.petrinet import PetriNet, Marking
+from pm4py.objects.bpmn.obj import BPMN
+from pm4py.objects.log.obj import EventLog
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+from pm4py.objects.process_tree.obj import ProcessTree
 
 INDEX_COLUMN = "@@index"
 
@@ -63,12 +64,12 @@ def read_pnml(file_path: str) -> Tuple[PetriNet, Marking, Marking]:
     final_marking
         Final marking
     """
-    from pm4py.objects.petri.importer import importer as pnml_importer
+    from pm4py.objects.petri_net.importer import importer as pnml_importer
     net, im, fm = pnml_importer.apply(file_path)
     return net, im, fm
 
 
-@deprecation.deprecated(deprecated_in='2.2.2', removed_in='2.3.0',
+@deprecation.deprecated(deprecated_in='2.2.2', removed_in='2.4.0',
                         details='read_petri_net is deprecated, use read_pnml instead')
 def read_petri_net(file_path: str) -> Tuple[PetriNet, Marking, Marking]:
     warnings.warn('read_petri_net is deprecated, use read_pnml instead', DeprecationWarning)
@@ -89,12 +90,12 @@ def read_petri_net(file_path: str) -> Tuple[PetriNet, Marking, Marking]:
     final_marking
         Final marking
     """
-    from pm4py.objects.petri.importer import importer as pnml_importer
+    from pm4py.objects.petri_net.importer import importer as pnml_importer
     net, im, fm = pnml_importer.apply(file_path)
     return net, im, fm
 
 
-def read_ptml(file_path: str) -> Tuple[PetriNet, Marking, Marking]:
+def read_ptml(file_path: str) -> ProcessTree:
     """
     Reads a process tree from a .ptml file
 
@@ -113,7 +114,7 @@ def read_ptml(file_path: str) -> Tuple[PetriNet, Marking, Marking]:
     return tree
 
 
-@deprecation.deprecated(deprecated_in='2.2.2', removed_in='2.3.0',
+@deprecation.deprecated(deprecated_in='2.2.2', removed_in='2.4.0',
                         details='read_process_tree is deprecated, use read_ptml instead')
 def read_process_tree(file_path: str) -> Tuple[PetriNet, Marking, Marking]:
     warnings.warn('read_process_tree is deprecated, use read_ptml instead', DeprecationWarning)
