@@ -14,13 +14,13 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.statistics.traces.log import case_arrival
+from pm4py.statistics.traces.generic.log import case_arrival
 from pm4py.simulation.montecarlo.utils import replay
 from pm4py.objects.petri_net.semantics import enabled_transitions, weak_execute
 from threading import Thread, Semaphore
 from statistics import median
 from pm4py.objects.log.obj import EventLog, Trace, Event
-from pm4py.util import constants, xes_constants
+from pm4py.util import xes_constants
 from pm4py.objects.stochastic_petri import utils as stochastic_utils
 import datetime
 from time import sleep, time
@@ -128,7 +128,7 @@ class SimulationThread(Thread):
             diagnostics = SimulationDiagnostics(self)
             diagnostics.start()
 
-        from intervaltree import IntervalTree, Interval
+        from intervaltree import Interval
 
         logging.basicConfig()
         logger = logging.getLogger(__name__)
@@ -302,7 +302,7 @@ def apply(log, net, im, fm, parameters=None):
     if parameters is None:
         parameters = {}
 
-    from intervaltree import IntervalTree, Interval
+    from intervaltree import IntervalTree
 
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters,
                                                xes_constants.DEFAULT_TIMESTAMP_KEY)
