@@ -15,6 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from typing import Optional, Dict, Any, List
+import os
 
 from pm4py.objects.bpmn.obj import BPMN
 from pm4py.objects.heuristics_net.obj import HeuristicsNet
@@ -26,6 +27,7 @@ from typing import Union, List
 from pm4py.util.pandas_utils import check_is_pandas_dataframe, check_pandas_dataframe_columns
 from pm4py.utils import get_properties
 from copy import copy
+import os
 
 
 def view_petri_net(petri_net: PetriNet, initial_marking: Marking, final_marking: Marking, format: str = "png"):
@@ -64,7 +66,7 @@ def save_vis_petri_net(petri_net: PetriNet, initial_marking: Marking, final_mark
     file_path
         Destination path
     """
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.petri_net import visualizer as pn_visualizer
     gviz = pn_visualizer.apply(petri_net, initial_marking, final_marking,
                                parameters={pn_visualizer.Variants.WO_DECORATION.value.Parameters.FORMAT: format})
@@ -114,7 +116,7 @@ def save_vis_dfg(dfg: dict, start_activities: dict, end_activities: dict, file_p
     file_path
         Destination path
     """
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.dfg import visualizer as dfg_visualizer
     dfg_parameters = dfg_visualizer.Variants.FREQUENCY.value.Parameters
     parameters = get_properties(log)
@@ -154,7 +156,7 @@ def save_vis_process_tree(tree: ProcessTree, file_path: str):
     file_path
         Destination path
     """
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.process_tree import visualizer as pt_visualizer
     parameters = pt_visualizer.Variants.WO_DECORATION.value.Parameters
     gviz = pt_visualizer.apply(tree, parameters={parameters.FORMAT: format})
@@ -172,7 +174,7 @@ def save_vis_bpmn(bpmn_graph: BPMN, file_path: str):
     file_path
         Destination path
     """
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.bpmn import visualizer as bpmn_visualizer
     parameters = bpmn_visualizer.Variants.CLASSIC.value.Parameters
     gviz = bpmn_visualizer.apply(bpmn_graph, parameters={parameters.FORMAT: format})
@@ -224,7 +226,7 @@ def save_vis_heuristics_net(heu_net: HeuristicsNet, file_path: str):
     file_path
         Destination path
     """
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.heuristics_net import visualizer as hn_visualizer
     parameters = hn_visualizer.Variants.PYDOTPLUS.value.Parameters
     gviz = hn_visualizer.apply(heu_net, parameters={parameters.FORMAT: format})
@@ -296,7 +298,7 @@ def save_vis_dotted_chart(log, file_path: str, attributes=None):
     attributes
         Attributes that should be used to construct the dotted chart (for example, ["concept:name", "org:resource"])
     """
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     log, attributes = __dotted_attribute_selection(log, attributes)
     from pm4py.visualization.dotted_chart import visualizer as dotted_chart_visualizer
     gviz = dotted_chart_visualizer.apply(log, attributes, parameters={"format": format})
@@ -375,7 +377,7 @@ def save_vis_case_duration_graph(log: Union[EventLog, pd.DataFrame], file_path:
     else:
         from pm4py.statistics.traces.generic.log import case_statistics
         graph = case_statistics.get_kde_caseduration(log, parameters=get_properties(log))
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.graphs import visualizer as graphs_visualizer
     graph_vis = graphs_visualizer.apply(graph[0], graph[1], variant=graphs_visualizer.Variants.CASES,
                                           parameters={"format": format})
@@ -424,7 +426,7 @@ def save_vis_events_per_time_graph(log: Union[EventLog, pd.DataFrame], file_path
     else:
         from pm4py.statistics.attributes.log import get as attributes_get
         graph = attributes_get.get_kde_date_attribute(log, parameters=get_properties(log))
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     from pm4py.visualization.graphs import visualizer as graphs_visualizer
     graph_vis = graphs_visualizer.apply(graph[0], graph[1], variant=graphs_visualizer.Variants.DATES,
                                           parameters={"format": format})
@@ -467,28 +469,14 @@ def save_vis_performance_spectrum(log: Union[EventLog, pd.DataFrame], activities
     perf_spectrum = performance_spectrum.apply(log, activities, parameters=get_properties(log))
     from pm4py.visualization.performance_spectrum import visualizer as perf_spectrum_visualizer
     from pm4py.visualization.performance_spectrum.variants import neato
-    format = file_path[file_path.index(".") + 1:].lower()
+    format = os.path.splitext(file_path)[1][1:]
     gviz = perf_spectrum_visualizer.apply(perf_spectrum, parameters={neato.Parameters.FORMAT.value: format})
     perf_spectrum_visualizer.save(gviz, file_path)
 
 
-def view_events_distribution_graph(log: Union[EventLog, pd.DataFrame], distr_type: str = "days_week", format="png"):
+def __builds_events_distribution_graph(log: Union[EventLog, pd.DataFrame], distr_type: str = "days_week"):
     """
-    Shows the distribution of the events in the specified dimension
-
-    Parameters
-    ----------------
-    log
-        Event log
-    distr_type
-        Type of distribution (default: days_week):
-        - days_month => Gets the distribution of the events among the days of a month (from 1 to 31)
-        - months => Gets the distribution of the events among the months (from 1 to 12)
-        - years => Gets the distribution of the events among the years of the event log
-        - hours => Gets the distribution of the events among the hours of a day (from 0 to 23)
-        - days_week => Gets the distribution of the events among the days of a week (from Monday to Sunday)
-    format
-        Format of the visualization (default: png)
+    Internal method to build the events distribution graph
     """
     if distr_type == "days_month":
         title = "Distribution of the Events over the Days of a Month"; x_axis = "Day of month"; y_axis = "Number of Events"
@@ -511,8 +499,57 @@ def view_events_distribution_graph(log: Union[EventLog, pd.DataFrame], distr_typ
         from pm4py.statistics.attributes.log import get as attributes_get
         x, y = attributes_get.get_events_distribution(log, distr_type=distr_type, parameters=get_properties(log))
 
+    return title, x_axis, y_axis, x, y
+
+
+def view_events_distribution_graph(log: Union[EventLog, pd.DataFrame], distr_type: str = "days_week", format="png"):
+    """
+    Shows the distribution of the events in the specified dimension
+
+    Parameters
+    ----------------
+    log
+        Event log
+    distr_type
+        Type of distribution (default: days_week):
+        - days_month => Gets the distribution of the events among the days of a month (from 1 to 31)
+        - months => Gets the distribution of the events among the months (from 1 to 12)
+        - years => Gets the distribution of the events among the years of the event log
+        - hours => Gets the distribution of the events among the hours of a day (from 0 to 23)
+        - days_week => Gets the distribution of the events among the days of a week (from Monday to Sunday)
+    format
+        Format of the visualization (default: png)
+    """
+    title, x_axis, y_axis, x, y = __builds_events_distribution_graph(log, distr_type)
     parameters = copy(get_properties(log))
     parameters["title"] = title; parameters["x_axis"] = x_axis; parameters["y_axis"] = y_axis; parameters["format"] = format
     from pm4py.visualization.graphs import visualizer as graphs_visualizer
     gviz = graphs_visualizer.apply(x, y, variant=graphs_visualizer.Variants.BARPLOT, parameters=parameters)
     graphs_visualizer.view(gviz)
+
+
+def save_vis_events_distribution_graph(log: Union[EventLog, pd.DataFrame], file_path: str, distr_type: str = "days_week"):
+    """
+    Saves the distribution of the events in a picture file
+
+    Parameters
+    ----------------
+    log
+        Event log
+    file_path
+        Destination path (including the extension)
+    distr_type
+        Type of distribution (default: days_week):
+        - days_month => Gets the distribution of the events among the days of a month (from 1 to 31)
+        - months => Gets the distribution of the events among the months (from 1 to 12)
+        - years => Gets the distribution of the events among the years of the event log
+        - hours => Gets the distribution of the events among the hours of a day (from 0 to 23)
+        - days_week => Gets the distribution of the events among the days of a week (from Monday to Sunday)
+    """
+    format = os.path.splitext(file_path)[1][1:]
+    title, x_axis, y_axis, x, y = __builds_events_distribution_graph(log, distr_type)
+    parameters = copy(get_properties(log))
+    parameters["title"] = title; parameters["x_axis"] = x_axis; parameters["y_axis"] = y_axis; parameters["format"] = format
+    from pm4py.visualization.graphs import visualizer as graphs_visualizer
+    gviz = graphs_visualizer.apply(x, y, variant=graphs_visualizer.Variants.BARPLOT, parameters=parameters)
+    graphs_visualizer.save(gviz, file_path)
