@@ -24,8 +24,20 @@ from pm4py.objects.dfg.utils import dfg_utils
 from pm4py.util import xes_constants as xes
 from pm4py.visualization.common.utils import *
 from pm4py.util import exec_utils
-from pm4py.visualization.dfg.parameters import Parameters
 from pm4py.statistics.sojourn_time.log import get as soj_time_get
+from enum import Enum
+from pm4py.util import constants
+
+
+class Parameters(Enum):
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+    FORMAT = "format"
+    MAX_NO_EDGES_IN_DIAGRAM = "maxNoOfEdgesInDiagram"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
+    START_TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_START_TIMESTAMP_KEY
+    FONT_SIZE = "font_size"
 
 
 def get_min_max_value(dfg):
@@ -81,40 +93,39 @@ def assign_penwidth_edges(dfg):
     return penwidth
 
 
-def get_activities_color(activities_count):
+def get_activities_color_soj_time(soj_time):
     """
-    Get frequency color for attributes
+    Gets the color for the activities based on the sojourn time
 
     Parameters
-    -----------
-    activities_count
-        Count of attributes in the log
+    ----------------
+    soj_time
+        Sojourn time
 
     Returns
-    -----------
-    activities_color
-        Color assigned to attributes in the graph
+    ----------------
+    act_color
+        Dictionary associating each activity to a color based on the sojourn time
     """
     activities_color = {}
 
-    min_value, max_value = get_min_max_value(activities_count)
+    min_soj_time, max_soj_time = get_min_max_value(soj_time)
 
-    for ac in activities_count:
-        v0 = activities_count[ac]
-        """transBaseColor = int(
-            255 - 100 * (v0 - min_value) / (max_value - min_value + 0.00001))
-        transBaseColorHex = str(hex(transBaseColor))[2:].upper()
-        v1 = "#" + transBaseColorHex + transBaseColorHex + "FF"""
+    for ac in soj_time:
+        act_soj_time = soj_time[ac]
 
-        v1 = get_trans_freq_color(v0, min_value, max_value)
+        trans_base_color = int(
+            255 - 100 * (act_soj_time - min_soj_time) / (max_soj_time - min_soj_time + 0.00001))
+        trans_base_color_hex = str(hex(trans_base_color))[2:].upper()
 
-        activities_color[ac] = v1
+        activities_color[ac] = "#" + "FF" + trans_base_color_hex + trans_base_color_hex
 
     return activities_color
 
 
 def graphviz_visualization(activities_count, dfg, image_format="png", measure="frequency",
-                           max_no_of_edges_in_diagram=170, start_activities=None, end_activities=None, soj_time=None):
+                           max_no_of_edges_in_diagram=100000, start_activities=None, end_activities=None, soj_time=None,
+                           font_size="12"):
     """
     Do GraphViz visualization of a DFG graph
 
@@ -174,7 +185,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         activities_in_dfg.add(edge[1])
 
     # assign attributes color
-    activities_color = get_activities_color(activities_count_int)
+    activities_color = get_activities_color_soj_time(soj_time)
 
     # represent nodes
     viz.attr('node', shape='box')
@@ -190,10 +201,11 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     for act in activities_to_include:
         if "frequency" in measure and act in activities_count_int:
             viz.node(str(hash(act)), act + " (" + str(activities_count_int[act]) + ")", style='filled',
-                     fillcolor=activities_color[act])
+                     fillcolor=activities_color[act], fontsize=font_size)
             activities_map[act] = str(hash(act))
         else:
-            viz.node(str(hash(act)), act + " (" + human_readable_stat(soj_time[act]) + ")")
+            viz.node(str(hash(act)), act + " (" + human_readable_stat(soj_time[act]) + ")", fontsize=font_size,
+                     style='filled', fillcolor=activities_color[act])
             activities_map[act] = str(hash(act))
 
     # make edges addition always in the same order
@@ -205,7 +217,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
             label = str(dfg[edge])
         else:
             label = human_readable_stat(dfg[edge])
-        viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, penwidth=str(penwidth[edge]))
+        viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, penwidth=str(penwidth[edge]), fontsize=font_size)
 
     start_activities_to_include = [act for act in start_activities if act in activities_map]
     end_activities_to_include = [act for act in end_activities if act in activities_map]
@@ -213,12 +225,12 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     if start_activities_to_include:
         viz.node("@@startnode", "@@S", style='filled', shape='circle', fillcolor="#32CD32", fontcolor="#32CD32")
         for act in start_activities_to_include:
-            viz.edge("@@startnode", activities_map[act])
+            viz.edge("@@startnode", activities_map[act], fontsize=font_size)
 
     if end_activities_to_include:
         viz.node("@@endnode", "@@E", style='filled', shape='circle', fillcolor="#FFA500", fontcolor="#FFA500")
         for act in end_activities_to_include:
-            viz.edge(activities_map[act], "@@endnode")
+            viz.edge(activities_map[act], "@@endnode", fontsize=font_size)
 
     viz.attr(overlap='false')
     viz.attr(fontsize='11')
@@ -234,9 +246,11 @@ def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
 
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
     image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
-    max_no_of_edges_in_diagram = exec_utils.get_param_value(Parameters.MAX_NO_EDGES_IN_DIAGRAM, parameters, 75)
+    max_no_of_edges_in_diagram = exec_utils.get_param_value(Parameters.MAX_NO_EDGES_IN_DIAGRAM, parameters, 100000)
     start_activities = exec_utils.get_param_value(Parameters.START_ACTIVITIES, parameters, [])
     end_activities = exec_utils.get_param_value(Parameters.END_ACTIVITIES, parameters, [])
+    font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 12)
+    font_size = str(font_size)
     activities = dfg_utils.get_activities_from_dfg(dfg)
 
     if activities_count is None:
@@ -253,4 +267,5 @@ def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
 
     return graphviz_visualization(activities_count, dfg, image_format=image_format, measure="performance",
                                   max_no_of_edges_in_diagram=max_no_of_edges_in_diagram,
-                                  start_activities=start_activities, end_activities=end_activities, soj_time=soj_time)
+                                  start_activities=start_activities, end_activities=end_activities, soj_time=soj_time,
+                                  font_size=font_size)
